==> openflowplugin-extension-nicira-0.8.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/updated/flow/instructions/instruction/instruction/apply/actions/_case/apply/actions/action/action/NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.updated.flow.instructions.instruction.instruction.apply.actions._case.apply.actions.action.action;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder} instances.
 *
 * @see NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder
 *
 */
public class NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder implements Builder<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase> {

    private NxRegMove _nxRegMove;


    Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>>, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> augmentation = Collections.emptyMap();

    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder() {
    }
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping arg) {
        this._nxRegMove = arg.getNxRegMove();
    }

    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder(NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase base) {
        this._nxRegMove = base.getNxRegMove();
        if (base instanceof NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl) {
            NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl impl = (NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>>, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> aug =((AugmentationHolder<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping) {
            this._nxRegMove = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping)arg).getNxRegMove();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping]");
    }

    public NxRegMove getNxRegMove() {
        return _nxRegMove;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder setNxRegMove(final NxRegMove value) {
        this._nxRegMove = value;
        return this;
    }
    
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> augmentationType, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase build() {
        return new NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl(this);
    }

    private static final class NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl implements NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase {
    
        private final NxRegMove _nxRegMove;
    
        private Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>>, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> augmentation = Collections.emptyMap();
    
        NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl(NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder base) {
            this._nxRegMove = base.getNxRegMove();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase> getImplementedInterface() {
            return NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase.class;
        }
    
        @Override
        public NxRegMove getNxRegMove() {
            return _nxRegMove;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxRegMove);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase other = (NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase)obj;
            if (!Objects.equals(_nxRegMove, other.getNxRegMove())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl otherImpl = (NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>>, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase");
            CodeHelpers.appendValue(helper, "_nxRegMove", _nxRegMove);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/updated/flow/instructions/instruction/instruction/apply/actions/_case/apply/actions/action/action/NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.updated.flow.instructions.instruction.instruction.apply.actions._case.apply.actions.action.action;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.reg.move.grouping.NxRegMove;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder} instances.
 *
 * @see NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder
 *
 */
public class NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder implements Builder<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase> {

    private NxRegMove _nxRegMove;


    Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>>, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> augmentation = Collections.emptyMap();

    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder() {
    }
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping arg) {
        this._nxRegMove = arg.getNxRegMove();
    }

    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder(NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase base) {
        this._nxRegMove = base.getNxRegMove();
        if (base instanceof NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl) {
            NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl impl = (NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>>, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> aug =((AugmentationHolder<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping) {
            this._nxRegMove = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping)arg).getNxRegMove();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping]");
    }

    public NxRegMove getNxRegMove() {
        return _nxRegMove;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder setNxRegMove(final NxRegMove value) {
        this._nxRegMove = value;
        return this;
    }
    
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> augmentationType, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase build() {
        return new NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl(this);
    }

    private static final class NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl implements NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase {
    
        private final NxRegMove _nxRegMove;
    
        private Map<Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>>, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> augmentation = Collections.emptyMap();
    
        NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl(NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseBuilder base) {
            this._nxRegMove = base.getNxRegMove();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase> getImplementedInterface() {
            return NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase.class;
        }
    
        @Override
        public NxRegMove getNxRegMove() {
            return _nxRegMove;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxRegMove);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase other = (NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase)obj;
            if (!Objects.equals(_nxRegMove, other.getNxRegMove())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl otherImpl = (NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>>, Augmentation<NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionRegMoveRpcUpdateFlowUpdatedApplyActionsCase");
            CodeHelpers.appendValue(helper, "_nxRegMove", _nxRegMove);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
